# Lectern snapshot

## Data pack

`@data_pack pack.mcmeta`

```json
{
  "pack": {
    "pack_format": 18,
    "description": ""
  }
}
```

### tcc

`@damage_type(strip_final_newline) tcc:boomerang`

```json
{
    "exhaustion": 0.1,
    "message_id": "tcc.boomerang",
    "scaling": "never"
}
```

`@loot_table(strip_final_newline) tcc:test`

```json
{}
```
